@@ -948,9 +948,17 @@ void EditProfileDialog::gotNewColorSchemes(const KNS3::Entry::List &changedEntri
 
 void EditProfileDialog::resetColorScheme()
 {
-    removeColorScheme();
-    // select the colorScheme used in the current profile
-    updateColorSchemeList(currentColorSchemeName());
+
+    QModelIndexList selected = _ui->colorSchemeList->selectionModel()->selectedIndexes();
+
+    if (!selected.isEmpty()) {
+        const QString &name = selected.first().data(Qt::UserRole + 1).value<const ColorScheme *>()->name();
+
+        ColorSchemeManager::instance()->deleteColorScheme(name);
+
+        // select the colorScheme used in the current profile
+        updateColorSchemeList(currentColorSchemeName());
+    }
 }
 
 void EditProfileDialog::showColorSchemeEditor(bool isNewScheme)
@@ -1218,6 +1226,9 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
     layout->addWidget(editor);
     layout->addWidget(buttonBox);
     dialog->setLayout(layout);
+    // see also the size set in the KeyBindingEditor constructor
+    dialog->setMinimumSize(480, 430);
+    dialog->resize(500, 500);
 
     if (dialog->exec() == QDialog::Accepted) {
         auto newTranslator = new KeyboardTranslator(*editor->translator());
